# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['ServiceAccount']


class ServiceAccount(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 identifier: Optional[pulumi.Input[str]] = None,
                 ingestion_policy: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Service Account Resource. This allows service accounts to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.ServiceAccount("basic",
            active=True,
            identifier="sa::tftesting")
        ```

        ## Import

        Service accounts can be imported using `identifier`, e.g.

        ```sh
         $ pulumi import wavefront:index/serviceAccount:ServiceAccount basic sa::tftesting
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Whether or not the service account is active
        :param pulumi.Input[str] description: The description of the service account
        :param pulumi.Input[str] identifier: The (unique) identifier of the service account to create. Must start with sa::
        :param pulumi.Input[str] ingestion_policy: ID of ingestion policy
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: List of permission to grant to this service account.  Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, `user_management`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_groups: List of user groups for this service account
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['active'] = active
            __props__['description'] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__['identifier'] = identifier
            __props__['ingestion_policy'] = ingestion_policy
            __props__['permissions'] = permissions
            __props__['user_groups'] = user_groups
        super(ServiceAccount, __self__).__init__(
            'wavefront:index/serviceAccount:ServiceAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            identifier: Optional[pulumi.Input[str]] = None,
            ingestion_policy: Optional[pulumi.Input[str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'ServiceAccount':
        """
        Get an existing ServiceAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Whether or not the service account is active
        :param pulumi.Input[str] description: The description of the service account
        :param pulumi.Input[str] identifier: The (unique) identifier of the service account to create. Must start with sa::
        :param pulumi.Input[str] ingestion_policy: ID of ingestion policy
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: List of permission to grant to this service account.  Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, `user_management`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_groups: List of user groups for this service account
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active"] = active
        __props__["description"] = description
        __props__["identifier"] = identifier
        __props__["ingestion_policy"] = ingestion_policy
        __props__["permissions"] = permissions
        __props__["user_groups"] = user_groups
        return ServiceAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether or not the service account is active
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the service account
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[str]:
        """
        The (unique) identifier of the service account to create. Must start with sa::
        """
        return pulumi.get(self, "identifier")

    @property
    @pulumi.getter(name="ingestionPolicy")
    def ingestion_policy(self) -> pulumi.Output[Optional[str]]:
        """
        ID of ingestion policy
        """
        return pulumi.get(self, "ingestion_policy")

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Sequence[str]]:
        """
        List of permission to grant to this service account.  Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, `user_management`
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> pulumi.Output[Sequence[str]]:
        """
        List of user groups for this service account
        """
        return pulumi.get(self, "user_groups")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['DerivedMetric']


class DerivedMetric(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_information: Optional[pulumi.Input[str]] = None,
                 minutes: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 query: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Derived Metric Resource. This allows derived metrics to be created,
        updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        derived = wavefront.DerivedMetric("derived",
            minutes=5,
            query="aliasMetric(5, \"some.metric\")")
        ```

        ## Import

        Derived Metrics can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/derivedMetric:DerivedMetric derived_metric 1577102900578
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] additional_information: User-supplied additional explanatory information for the derived metric
        :param pulumi.Input[int] minutes: How frequently the query generating the derived metric is run
        :param pulumi.Input[str] name: The name of the Derived Metric in Wavefront
        :param pulumi.Input[str] query: A Wavefront query that is evaluated at regular intervals (default `1m`)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A set of tags to assign to this resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_information'] = additional_information
            if minutes is None and not opts.urn:
                raise TypeError("Missing required property 'minutes'")
            __props__['minutes'] = minutes
            __props__['name'] = name
            if query is None and not opts.urn:
                raise TypeError("Missing required property 'query'")
            __props__['query'] = query
            __props__['tags'] = tags
        super(DerivedMetric, __self__).__init__(
            'wavefront:index/derivedMetric:DerivedMetric',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_information: Optional[pulumi.Input[str]] = None,
            minutes: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            query: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'DerivedMetric':
        """
        Get an existing DerivedMetric resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] additional_information: User-supplied additional explanatory information for the derived metric
        :param pulumi.Input[int] minutes: How frequently the query generating the derived metric is run
        :param pulumi.Input[str] name: The name of the Derived Metric in Wavefront
        :param pulumi.Input[str] query: A Wavefront query that is evaluated at regular intervals (default `1m`)
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A set of tags to assign to this resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_information"] = additional_information
        __props__["minutes"] = minutes
        __props__["name"] = name
        __props__["query"] = query
        __props__["tags"] = tags
        return DerivedMetric(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalInformation")
    def additional_information(self) -> pulumi.Output[Optional[str]]:
        """
        User-supplied additional explanatory information for the derived metric
        """
        return pulumi.get(self, "additional_information")

    @property
    @pulumi.getter
    def minutes(self) -> pulumi.Output[int]:
        """
        How frequently the query generating the derived metric is run
        """
        return pulumi.get(self, "minutes")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Derived Metric in Wavefront
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def query(self) -> pulumi.Output[str]:
        """
        A Wavefront query that is evaluated at regular intervals (default `1m`)
        """
        return pulumi.get(self, "query")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A set of tags to assign to this resource.
        """
        return pulumi.get(self, "tags")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['ExternalLink']


class ExternalLink(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 is_log_integration: Optional[pulumi.Input[bool]] = None,
                 metric_filter_regex: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 point_tag_filter_regexes: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 source_filter_regex: Optional[pulumi.Input[str]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront External Link Resource. This allows external links to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.ExternalLink("basic",
            description="An external link description",
            template="https://example.com/source={{{source}}}&startTime={{startEpochMillis}}")
        ```

        ## Import

        Maintenance windows can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/externalLink:ExternalLink basic fVj6fz6zYC4aBkID
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Human-readable description for this link
        :param pulumi.Input[bool] is_log_integration: Whether this is a "Log Integration" subType of external link
        :param pulumi.Input[str] metric_filter_regex: Controls whether a link is displayed in the context menu of a highlighted series. If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed.
        :param pulumi.Input[str] name: The name of the external link
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] point_tag_filter_regexes: Controls whether a link is displayed in the context menu of a highlighted series. This is a map from string to regular expression. The highlighted series must contain point tags whose keys are present in the keys of this map and whose values match the regular expressions associated with those keys in order for the link to be displayed
        :param pulumi.Input[str] source_filter_regex: Controls whether a link is displayed in the context menu of a highlighted series. If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed.
        :param pulumi.Input[str] template: The mustache template for this link. The template must expand to a full URL, including scheme, origin, etc.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            __props__['is_log_integration'] = is_log_integration
            __props__['metric_filter_regex'] = metric_filter_regex
            __props__['name'] = name
            __props__['point_tag_filter_regexes'] = point_tag_filter_regexes
            __props__['source_filter_regex'] = source_filter_regex
            if template is None and not opts.urn:
                raise TypeError("Missing required property 'template'")
            __props__['template'] = template
        super(ExternalLink, __self__).__init__(
            'wavefront:index/externalLink:ExternalLink',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            is_log_integration: Optional[pulumi.Input[bool]] = None,
            metric_filter_regex: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            point_tag_filter_regexes: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            source_filter_regex: Optional[pulumi.Input[str]] = None,
            template: Optional[pulumi.Input[str]] = None) -> 'ExternalLink':
        """
        Get an existing ExternalLink resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Human-readable description for this link
        :param pulumi.Input[bool] is_log_integration: Whether this is a "Log Integration" subType of external link
        :param pulumi.Input[str] metric_filter_regex: Controls whether a link is displayed in the context menu of a highlighted series. If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed.
        :param pulumi.Input[str] name: The name of the external link
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] point_tag_filter_regexes: Controls whether a link is displayed in the context menu of a highlighted series. This is a map from string to regular expression. The highlighted series must contain point tags whose keys are present in the keys of this map and whose values match the regular expressions associated with those keys in order for the link to be displayed
        :param pulumi.Input[str] source_filter_regex: Controls whether a link is displayed in the context menu of a highlighted series. If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed.
        :param pulumi.Input[str] template: The mustache template for this link. The template must expand to a full URL, including scheme, origin, etc.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["description"] = description
        __props__["is_log_integration"] = is_log_integration
        __props__["metric_filter_regex"] = metric_filter_regex
        __props__["name"] = name
        __props__["point_tag_filter_regexes"] = point_tag_filter_regexes
        __props__["source_filter_regex"] = source_filter_regex
        __props__["template"] = template
        return ExternalLink(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Human-readable description for this link
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="isLogIntegration")
    def is_log_integration(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether this is a "Log Integration" subType of external link
        """
        return pulumi.get(self, "is_log_integration")

    @property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> pulumi.Output[Optional[str]]:
        """
        Controls whether a link is displayed in the context menu of a highlighted series. If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed.
        """
        return pulumi.get(self, "metric_filter_regex")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the external link
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="pointTagFilterRegexes")
    def point_tag_filter_regexes(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Controls whether a link is displayed in the context menu of a highlighted series. This is a map from string to regular expression. The highlighted series must contain point tags whose keys are present in the keys of this map and whose values match the regular expressions associated with those keys in order for the link to be displayed
        """
        return pulumi.get(self, "point_tag_filter_regexes")

    @property
    @pulumi.getter(name="sourceFilterRegex")
    def source_filter_regex(self) -> pulumi.Output[Optional[str]]:
        """
        Controls whether a link is displayed in the context menu of a highlighted series. If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed.
        """
        return pulumi.get(self, "source_filter_regex")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[str]:
        """
        The mustache template for this link. The template must expand to a full URL, including scheme, origin, etc.
        """
        return pulumi.get(self, "template")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['Alert']


class Alert(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_information: Optional[pulumi.Input[str]] = None,
                 alert_type: Optional[pulumi.Input[str]] = None,
                 can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 can_views: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 condition: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 display_expression: Optional[pulumi.Input[str]] = None,
                 minutes: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notification_resend_frequency_minutes: Optional[pulumi.Input[int]] = None,
                 resolve_after_minutes: Optional[pulumi.Input[int]] = None,
                 severity: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 threshold_targets: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Alert resource.  This allows alerts to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        foobar = wavefront.Alert("foobar",
            condition="100-ts(\"cpu.usage_idle\", environment=preprod and cpu=cpu-total ) > 80",
            display_expression="100-ts(\"cpu.usage_idle\", environment=preprod and cpu=cpu-total )",
            minutes=5,
            resolve_after_minutes=5,
            severity="WARN",
            tags=[
                "terraform",
                "test",
            ],
            target="test@example.com")
        ```

        ## Import

        Alerts can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/alert:Alert alert_target 1479868728473
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] additional_information: User-supplied additional explanatory information for this alert.
               Useful for linking runbooks, migrations...etc
        :param pulumi.Input[str] alert_type: The type of alert in Wavefront.  Either `CLASSIC` (default) 
               or `THRESHOLD`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_modifies: A list of users or groups that can modify this resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_views: A list of users or groups that can view this resource.
        :param pulumi.Input[str] condition: A Wavefront query that is evaluated at regular intervals (default 1m).
               The alert fires and notifications are triggered when data series matching this query evaluates
               to a non-zero value for a set number of consecutive minutes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] conditions: a string->string map of `severity` to `condition` 
               for which this alert will trigger.
        :param pulumi.Input[str] display_expression: A second query whose results are displayed in the alert user
               interface instead of the condition query.  This field is often used to display a version
               of the condition query with Boolean operators removed so that numerical values are plotted.
        :param pulumi.Input[int] minutes: The number of consecutive minutes that a series matching the condition query must 
               evaluate to "true" (non-zero value) before the alert fires.
        :param pulumi.Input[str] name: The name of the alert as it is displayed in Wavefront.
        :param pulumi.Input[int] notification_resend_frequency_minutes: How often to re-trigger a continually failing alert. 
               If absent or <= 0, no re-triggering occur.
        :param pulumi.Input[int] resolve_after_minutes: The number of consecutive minutes that a firing series matching the condition
               query must evaluate to "false" (zero value) before the alert resolves.  When unset, this default sto
               the same value as `minutes`.
        :param pulumi.Input[str] severity: - Severity of the alert, valid values are `INFO`, `SMOKE`, `WARN`, `SEVERE`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[str] target: A comma-separated list of the email address or integration endpoint 
               (such as PagerDuty or web hook) to notify when the alert status changes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] threshold_targets: Targets for severity
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_information'] = additional_information
            __props__['alert_type'] = alert_type
            __props__['can_modifies'] = can_modifies
            __props__['can_views'] = can_views
            __props__['condition'] = condition
            __props__['conditions'] = conditions
            __props__['display_expression'] = display_expression
            if minutes is None and not opts.urn:
                raise TypeError("Missing required property 'minutes'")
            __props__['minutes'] = minutes
            __props__['name'] = name
            __props__['notification_resend_frequency_minutes'] = notification_resend_frequency_minutes
            __props__['resolve_after_minutes'] = resolve_after_minutes
            __props__['severity'] = severity
            if tags is None and not opts.urn:
                raise TypeError("Missing required property 'tags'")
            __props__['tags'] = tags
            __props__['target'] = target
            __props__['threshold_targets'] = threshold_targets
        super(Alert, __self__).__init__(
            'wavefront:index/alert:Alert',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_information: Optional[pulumi.Input[str]] = None,
            alert_type: Optional[pulumi.Input[str]] = None,
            can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            can_views: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            condition: Optional[pulumi.Input[str]] = None,
            conditions: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            display_expression: Optional[pulumi.Input[str]] = None,
            minutes: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            notification_resend_frequency_minutes: Optional[pulumi.Input[int]] = None,
            resolve_after_minutes: Optional[pulumi.Input[int]] = None,
            severity: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            target: Optional[pulumi.Input[str]] = None,
            threshold_targets: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'Alert':
        """
        Get an existing Alert resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] additional_information: User-supplied additional explanatory information for this alert.
               Useful for linking runbooks, migrations...etc
        :param pulumi.Input[str] alert_type: The type of alert in Wavefront.  Either `CLASSIC` (default) 
               or `THRESHOLD`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_modifies: A list of users or groups that can modify this resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_views: A list of users or groups that can view this resource.
        :param pulumi.Input[str] condition: A Wavefront query that is evaluated at regular intervals (default 1m).
               The alert fires and notifications are triggered when data series matching this query evaluates
               to a non-zero value for a set number of consecutive minutes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] conditions: a string->string map of `severity` to `condition` 
               for which this alert will trigger.
        :param pulumi.Input[str] display_expression: A second query whose results are displayed in the alert user
               interface instead of the condition query.  This field is often used to display a version
               of the condition query with Boolean operators removed so that numerical values are plotted.
        :param pulumi.Input[int] minutes: The number of consecutive minutes that a series matching the condition query must 
               evaluate to "true" (non-zero value) before the alert fires.
        :param pulumi.Input[str] name: The name of the alert as it is displayed in Wavefront.
        :param pulumi.Input[int] notification_resend_frequency_minutes: How often to re-trigger a continually failing alert. 
               If absent or <= 0, no re-triggering occur.
        :param pulumi.Input[int] resolve_after_minutes: The number of consecutive minutes that a firing series matching the condition
               query must evaluate to "false" (zero value) before the alert resolves.  When unset, this default sto
               the same value as `minutes`.
        :param pulumi.Input[str] severity: - Severity of the alert, valid values are `INFO`, `SMOKE`, `WARN`, `SEVERE`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[str] target: A comma-separated list of the email address or integration endpoint 
               (such as PagerDuty or web hook) to notify when the alert status changes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] threshold_targets: Targets for severity
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_information"] = additional_information
        __props__["alert_type"] = alert_type
        __props__["can_modifies"] = can_modifies
        __props__["can_views"] = can_views
        __props__["condition"] = condition
        __props__["conditions"] = conditions
        __props__["display_expression"] = display_expression
        __props__["minutes"] = minutes
        __props__["name"] = name
        __props__["notification_resend_frequency_minutes"] = notification_resend_frequency_minutes
        __props__["resolve_after_minutes"] = resolve_after_minutes
        __props__["severity"] = severity
        __props__["tags"] = tags
        __props__["target"] = target
        __props__["threshold_targets"] = threshold_targets
        return Alert(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalInformation")
    def additional_information(self) -> pulumi.Output[Optional[str]]:
        """
        User-supplied additional explanatory information for this alert.
        Useful for linking runbooks, migrations...etc
        """
        return pulumi.get(self, "additional_information")

    @property
    @pulumi.getter(name="alertType")
    def alert_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of alert in Wavefront.  Either `CLASSIC` (default) 
        or `THRESHOLD`
        """
        return pulumi.get(self, "alert_type")

    @property
    @pulumi.getter(name="canModifies")
    def can_modifies(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of users or groups that can modify this resource.
        """
        return pulumi.get(self, "can_modifies")

    @property
    @pulumi.getter(name="canViews")
    def can_views(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of users or groups that can view this resource.
        """
        return pulumi.get(self, "can_views")

    @property
    @pulumi.getter
    def condition(self) -> pulumi.Output[Optional[str]]:
        """
        A Wavefront query that is evaluated at regular intervals (default 1m).
        The alert fires and notifications are triggered when data series matching this query evaluates
        to a non-zero value for a set number of consecutive minutes.
        """
        return pulumi.get(self, "condition")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        a string->string map of `severity` to `condition` 
        for which this alert will trigger.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="displayExpression")
    def display_expression(self) -> pulumi.Output[Optional[str]]:
        """
        A second query whose results are displayed in the alert user
        interface instead of the condition query.  This field is often used to display a version
        of the condition query with Boolean operators removed so that numerical values are plotted.
        """
        return pulumi.get(self, "display_expression")

    @property
    @pulumi.getter
    def minutes(self) -> pulumi.Output[int]:
        """
        The number of consecutive minutes that a series matching the condition query must 
        evaluate to "true" (non-zero value) before the alert fires.
        """
        return pulumi.get(self, "minutes")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the alert as it is displayed in Wavefront.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="notificationResendFrequencyMinutes")
    def notification_resend_frequency_minutes(self) -> pulumi.Output[Optional[int]]:
        """
        How often to re-trigger a continually failing alert. 
        If absent or <= 0, no re-triggering occur.
        """
        return pulumi.get(self, "notification_resend_frequency_minutes")

    @property
    @pulumi.getter(name="resolveAfterMinutes")
    def resolve_after_minutes(self) -> pulumi.Output[Optional[int]]:
        """
        The number of consecutive minutes that a firing series matching the condition
        query must evaluate to "false" (zero value) before the alert resolves.  When unset, this default sto
        the same value as `minutes`.
        """
        return pulumi.get(self, "resolve_after_minutes")

    @property
    @pulumi.getter
    def severity(self) -> pulumi.Output[str]:
        """
        - Severity of the alert, valid values are `INFO`, `SMOKE`, `WARN`, `SEVERE`.
        """
        return pulumi.get(self, "severity")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence[str]]:
        """
        A set of tags to assign to this resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[Optional[str]]:
        """
        A comma-separated list of the email address or integration endpoint 
        (such as PagerDuty or web hook) to notify when the alert status changes.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="thresholdTargets")
    def threshold_targets(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Targets for severity
        """
        return pulumi.get(self, "threshold_targets")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "additional_information": "additionalInformation",
    "additional_tags": "additionalTags",
    "alert_type": "alertType",
    "api_key": "apiKey",
    "app_filter_regex": "appFilterRegex",
    "app_filter_regexes": "appFilterRegexes",
    "bucket_name": "bucketName",
    "can_modifies": "canModifies",
    "can_views": "canViews",
    "category_filters": "categoryFilters",
    "client_id": "clientId",
    "client_secret": "clientSecret",
    "content_type": "contentType",
    "controller_name": "controllerName",
    "custom_headers": "customHeaders",
    "dashboard_json": "dashboardJson",
    "display_expression": "displayExpression",
    "display_query_parameters": "displayQueryParameters",
    "display_section_table_of_contents": "displaySectionTableOfContents",
    "email_subject": "emailSubject",
    "enable_app_infra_metrics": "enableAppInfraMetrics",
    "enable_backend_metrics": "enableBackendMetrics",
    "enable_business_trx_metrics": "enableBusinessTrxMetrics",
    "enable_error_metrics": "enableErrorMetrics",
    "enable_individual_node_metrics": "enableIndividualNodeMetrics",
    "enable_overall_perf_metrics": "enableOverallPerfMetrics",
    "enable_rollup": "enableRollup",
    "enable_service_endpoint_metrics": "enableServiceEndpointMetrics",
    "encrypted_password": "encryptedPassword",
    "end_time_in_seconds": "endTimeInSeconds",
    "event_filter_type": "eventFilterType",
    "external_id": "externalId",
    "filter_rule": "filterRule",
    "force_save": "forceSave",
    "host_filter_regex": "hostFilterRegex",
    "host_tag_group_host_names_group_anded": "hostTagGroupHostNamesGroupAnded",
    "hostname_tags": "hostnameTags",
    "http_proxy": "httpProxy",
    "ingestion_policy": "ingestionPolicy",
    "instance_selection_tags": "instanceSelectionTags",
    "is_html_content": "isHtmlContent",
    "is_log_integration": "isLogIntegration",
    "json_key": "jsonKey",
    "metric_filter_regex": "metricFilterRegex",
    "metric_filters": "metricFilters",
    "notification_resend_frequency_minutes": "notificationResendFrequencyMinutes",
    "parameter_details": "parameterDetails",
    "point_tag_filter_regex": "pointTagFilterRegex",
    "point_tag_filter_regexes": "pointTagFilterRegexes",
    "project_id": "projectId",
    "relevant_customer_tags": "relevantCustomerTags",
    "relevant_host_names": "relevantHostNames",
    "relevant_host_tags": "relevantHostTags",
    "relevant_host_tags_anded": "relevantHostTagsAnded",
    "resolve_after_minutes": "resolveAfterMinutes",
    "resource_group_filters": "resourceGroupFilters",
    "role_arn": "roleArn",
    "service_refresh_rate_in_minutes": "serviceRefreshRateInMinutes",
    "source_filter_regex": "sourceFilterRegex",
    "start_time_in_seconds": "startTimeInSeconds",
    "target_id": "targetId",
    "threshold_targets": "thresholdTargets",
    "user_groups": "userGroups",
    "user_name": "userName",
    "volume_selection_tags": "volumeSelectionTags",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "additionalInformation": "additional_information",
    "additionalTags": "additional_tags",
    "alertType": "alert_type",
    "apiKey": "api_key",
    "appFilterRegex": "app_filter_regex",
    "appFilterRegexes": "app_filter_regexes",
    "bucketName": "bucket_name",
    "canModifies": "can_modifies",
    "canViews": "can_views",
    "categoryFilters": "category_filters",
    "clientId": "client_id",
    "clientSecret": "client_secret",
    "contentType": "content_type",
    "controllerName": "controller_name",
    "customHeaders": "custom_headers",
    "dashboardJson": "dashboard_json",
    "displayExpression": "display_expression",
    "displayQueryParameters": "display_query_parameters",
    "displaySectionTableOfContents": "display_section_table_of_contents",
    "emailSubject": "email_subject",
    "enableAppInfraMetrics": "enable_app_infra_metrics",
    "enableBackendMetrics": "enable_backend_metrics",
    "enableBusinessTrxMetrics": "enable_business_trx_metrics",
    "enableErrorMetrics": "enable_error_metrics",
    "enableIndividualNodeMetrics": "enable_individual_node_metrics",
    "enableOverallPerfMetrics": "enable_overall_perf_metrics",
    "enableRollup": "enable_rollup",
    "enableServiceEndpointMetrics": "enable_service_endpoint_metrics",
    "encryptedPassword": "encrypted_password",
    "endTimeInSeconds": "end_time_in_seconds",
    "eventFilterType": "event_filter_type",
    "externalId": "external_id",
    "filterRule": "filter_rule",
    "forceSave": "force_save",
    "hostFilterRegex": "host_filter_regex",
    "hostTagGroupHostNamesGroupAnded": "host_tag_group_host_names_group_anded",
    "hostnameTags": "hostname_tags",
    "httpProxy": "http_proxy",
    "ingestionPolicy": "ingestion_policy",
    "instanceSelectionTags": "instance_selection_tags",
    "isHtmlContent": "is_html_content",
    "isLogIntegration": "is_log_integration",
    "jsonKey": "json_key",
    "metricFilterRegex": "metric_filter_regex",
    "metricFilters": "metric_filters",
    "notificationResendFrequencyMinutes": "notification_resend_frequency_minutes",
    "parameterDetails": "parameter_details",
    "pointTagFilterRegex": "point_tag_filter_regex",
    "pointTagFilterRegexes": "point_tag_filter_regexes",
    "projectId": "project_id",
    "relevantCustomerTags": "relevant_customer_tags",
    "relevantHostNames": "relevant_host_names",
    "relevantHostTags": "relevant_host_tags",
    "relevantHostTagsAnded": "relevant_host_tags_anded",
    "resolveAfterMinutes": "resolve_after_minutes",
    "resourceGroupFilters": "resource_group_filters",
    "roleArn": "role_arn",
    "serviceRefreshRateInMinutes": "service_refresh_rate_in_minutes",
    "sourceFilterRegex": "source_filter_regex",
    "startTimeInSeconds": "start_time_in_seconds",
    "targetId": "target_id",
    "thresholdTargets": "threshold_targets",
    "userGroups": "user_groups",
    "userName": "user_name",
    "volumeSelectionTags": "volume_selection_tags",
}
